.. Copyright (C) 2017 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

Ansible can be extended in various ways by the use of `custom plugins <https://docs.ansible.com/ansible/latest/dev_guide/developing_plugins.html>`_.
This role contains a set of custom Ansible plugins used by various DebOps
roles. The plugins are enabled by including this role as a dependency of
another role.
